@@ -3,10 +3,14 @@ package OpenTracing::Batch;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '1.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use parent qw(OpenTracing::Common);
 
+no indirect;
+use utf8;
+
 =encoding utf8
 
 =head1 NAME
@@ -25,6 +29,8 @@ class.
 use Time::HiRes;
 use Scalar::Util ();
 
+use OpenTracing::Process;
+
 =head1 METHODS
 
 =head2 process
@@ -43,7 +49,7 @@ Returns an arrayref of L<OpenTracing::Span> instances.
 =cut
 
 sub spans {
-    shift->{spans}
+    shift->{spans} //= []
 }
 
 =head2 span_list
@@ -119,5 +125,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2018-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2018-2020. Licensed under the same terms as Perl itself.
 
