@@ -3,7 +3,11 @@ package OpenTracing::Common;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '1.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
+
+no indirect;
+use utf8;
 
 =encoding utf8
 
@@ -32,5 +36,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2018-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2018-2020. Licensed under the same terms as Perl itself.
 
