@@ -3,10 +3,14 @@ package OpenTracing::Process;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '1.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use parent qw(OpenTracing::Common);
 
+no indirect;
+use utf8;
+
 =encoding utf8
 
 =head1 NAME
@@ -28,7 +32,7 @@ The process name. Freeform text string.
 
 =cut
 
-sub name { shift->{name} }
+sub name { shift->{name} //= "$0" }
 
 =head2 tags
 
@@ -48,6 +52,12 @@ sub tag_list {
     (shift->{tags} //= [])->@*
 }
 
+sub tag : method {
+    my ($self, %args) = @_;
+    @{$self->{tags}}{keys %args} = values %args;
+    return $self;
+}
+
 1;
 
 __END__
@@ -58,5 +68,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2018-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2018-2020. Licensed under the same terms as Perl itself.
 
