@@ -3,10 +3,14 @@ package OpenTracing::Span;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '1.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use parent qw(OpenTracing::Common);
 
+no indirect;
+use utf8;
+
 =encoding utf8
 
 =head1 NAME
@@ -22,7 +26,21 @@ L<https://opentracing.io/docs/overview/spans/>
 =cut
 
 use Time::HiRes ();
-use Math::Random::Secure ();
+use Bytes::Random::Secure qw(random_bytes_hex);
+
+sub new {
+    my ($class, %args) = @_;
+    $args{operation_name} //= (caller 1)[3];
+    if(my $parent = $args{parent}) {
+        $args{parent_id} = $parent->id;
+        $args{trace_id} = $parent->trace_id;
+    }
+
+    # Alternatively reduce { $a * 1_000_000 + $b } Time::HiRes::gettimeofday(),
+    # but the time() version benchmarks to ~3x faster
+    $args{start_time} //= int(Time::HiRes::time() * 1_000_000);
+    bless \%args, $class
+}
 
 =head2 trace_id
 
@@ -30,7 +48,7 @@ The trace ID for this span. Multiple spans are grouped under a single trace.
 
 =cut
 
-sub trace_id { shift->{trace_id} //= Math::Random::Secure::irand(2**63) }
+sub trace_id { shift->{trace_id} //= random_bytes_hex(16) }
 
 =head2 id
 
@@ -38,7 +56,7 @@ The span ID. This should be unique.
 
 =cut
 
-sub id { shift->{id} //= Math::Random::Secure::irand(2**63) }
+sub id { shift->{id} //= random_bytes_hex(8) }
 
 =head2 parent_id
 
@@ -46,7 +64,7 @@ Parent span ID. 0 if there isn't one.
 
 =cut
 
-sub parent_id { shift->{parent_id} //= 0 }
+sub parent_id { shift->{parent_id} //= '0' x 8; }
 
 =head2 flags
 
@@ -62,7 +80,17 @@ Exact time this span started, in microseconds.
 
 =cut
 
-sub start_time { shift->{start_time} //= (Time::HiRes::time() * 1_000_000) }
+sub start_time { shift->{start_time} //= int(Time::HiRes::time() * 1_000_000) }
+
+=head2 start_time
+
+Exact time this span finished, in microseconds.
+
+Returns C<undef> if the span is not yet finished.
+
+=cut
+
+sub finish_time { shift->{finish_time} }
 
 =head2 duration
 
@@ -70,7 +98,11 @@ Total duration of this span, including any nested spans.
 
 =cut
 
-sub duration { shift->{duration} }
+sub duration {
+    my ($self) = @_;
+    return undef unless defined $self->{finish_time};
+    $self->{duration} //= $self->finish_time - $self->start_time;
+}
 
 =head2 operation_name
 
@@ -126,27 +158,37 @@ Records a single log message.
 sub log : method {
     my ($self, $message, %args) = @_;
     $args{message} = $message;
-    my $timestamp = delete($args{timestamp}) // Time::HiRes::time() * 1_000_000;
+    my $timestamp = delete($args{timestamp}) // int(Time::HiRes::time() * 1_000_000);
     push +($self->{logs} //= [])->@*, my $log = OpenTracing::Log->new(
-        tags => {
-            message => $message,
-        },
+        tags => \%args,
         timestamp => $timestamp
     );
     $log;
 }
 
+sub tag : method {
+    my ($self, %args) = @_;
+    @{$self->{tags}}{keys %args} = values %args;
+    return $self;
+}
+
 sub tracer { shift->{tracer} }
 
+sub is_finished { defined shift->{finish_time} }
+
 =head2 finish
 
-Mark this span as finished (populating the L</duration> field).
+Mark this span as finished (populating the L</finish_time> field).
 
 =cut
 
 sub finish {
-    my ($self) = @_;
-    $self->{duration} = (Time::HiRes::time * 1_000_000) - $self->start_time;
+    my ($self, $ts) = @_;
+    unless($self->is_finished) {
+        $ts //= int(Time::HiRes::time * 1_000_000);
+        $self->{finish_time} = $ts;
+        $self->tracer->finish_span($self);
+    }
     $self
 }
 
@@ -160,5 +202,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2018-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2018-2020. Licensed under the same terms as Perl itself.
 
