@@ -3,10 +3,14 @@ package OpenTracing::SpanContext;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '1.000'; # VERSION
+our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use parent qw(OpenTracing::Common);
 
+no indirect;
+use utf8;
+
 =encoding utf8
 
 =head1 NAME
@@ -17,11 +21,6 @@ OpenTracing::SpanContext - tracks IDs and baggage for spans
 
 =cut
 
-sub new {
-    my ($class, %args) = @_;
-    bless \%args, $class;
-}
-
 =head2 span
 
 Returns the L<OpenTracing::Span> instance that this wraps.
@@ -78,5 +77,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2018-2019. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2018-2020. Licensed under the same terms as Perl itself.
 
